JBoss Tools SVN: r41485 - in trunk/build/aggregate: coretests-site and 5 other directories.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2012-05-28 16:14:03 -0400 (Mon, 28 May 2012)
New Revision: 41485
Modified:
trunk/build/aggregate/DEPRECATED_bottests-site/site/associate.properties
trunk/build/aggregate/coretests-site/associate.properties
trunk/build/aggregate/site/associate.properties
trunk/build/aggregate/soa-site/plugins/org.jboss.tools.central.discovery.soa-tooling/plugin.properties
trunk/build/aggregate/soa-site/site/associate.properties
trunk/build/aggregate/soatests-site/site/associate.properties
trunk/build/aggregate/webtools-site/associate.properties
Log:
JBIDE-11622 move trunk to juno
Modified: trunk/build/aggregate/DEPRECATED_bottests-site/site/associate.properties
===================================================================
--- trunk/build/aggregate/DEPRECATED_bottests-site/site/associate.properties 2012-05-28 18:37:19 UTC (rev 41484)
+++ trunk/build/aggregate/DEPRECATED_bottests-site/site/associate.properties 2012-05-28 20:14:03 UTC (rev 41485)
@@ -4,4 +4,4 @@
#update.site.version=3.2.0.M2.2010-07-16_13-26-18-H21
# associate sites to add to the resulting repo
-associate.sites=http://download.jboss.org/jbosstools/updates/indigo/SR2/,http://download.jboss.org/jbosstools/updates/development/indigo/
+associate.sites=http://download.jboss.org/jbosstools/updates/juno/M6/,http://download.jboss.org/jbosstools/updates/development/juno/
Modified: trunk/build/aggregate/coretests-site/associate.properties
===================================================================
--- trunk/build/aggregate/coretests-site/associate.properties 2012-05-28 18:37:19 UTC (rev 41484)
+++ trunk/build/aggregate/coretests-site/associate.properties 2012-05-28 20:14:03 UTC (rev 41485)
@@ -4,4 +4,4 @@
#update.site.version=3.2.0.M2.2010-07-16_13-26-18-H21
# associate sites to add to the resulting repo
-associate.sites=http://download.jboss.org/jbosstools/updates/indigo/SR2/,http://download.jboss.org/jbosstools/updates/development/indigo/
+associate.sites=http://download.jboss.org/jbosstools/updates/juno/M6/,http://download.jboss.org/jbosstools/updates/development/juno/
Modified: trunk/build/aggregate/site/associate.properties
===================================================================
--- trunk/build/aggregate/site/associate.properties 2012-05-28 18:37:19 UTC (rev 41484)
+++ trunk/build/aggregate/site/associate.properties 2012-05-28 20:14:03 UTC (rev 41485)
@@ -4,4 +4,4 @@
#update.site.version=3.2.0.M2.2010-07-16_13-26-18-H21
# associate sites to add to the resulting repo
-associate.sites=http://download.jboss.org/jbosstools/updates/indigo/SR2/
+associate.sites=http://download.jboss.org/jbosstools/updates/juno/M6/
Modified: trunk/build/aggregate/soa-site/plugins/org.jboss.tools.central.discovery.soa-tooling/plugin.properties
===================================================================
--- trunk/build/aggregate/soa-site/plugins/org.jboss.tools.central.discovery.soa-tooling/plugin.properties 2012-05-28 18:37:19 UTC (rev 41484)
+++ trunk/build/aggregate/soa-site/plugins/org.jboss.tools.central.discovery.soa-tooling/plugin.properties 2012-05-28 20:14:03 UTC (rev 41485)
@@ -5,11 +5,9 @@
#jboss.soa.update.url = http://download.jboss.org/jbosstools/updates/nightly/soa-tooling/trunk/
# QE testing - nightly from stable branch
-#jboss.soa.update.url = http://download.jboss.org/jbosstools/updates/nightly/soa-tooling/3.3.indigo/
-# QE testing - staging (for a specific milestone)
-#http://download.jboss.org/jbosstools/updates/JBossTools-3.3.0.M5.soa-tooling/
+#jboss.soa.update.url = http://download.jboss.org/jbosstools/updates/nightly/soa-tooling/3.4.juno/
# staging (latest EA / milestone)
-jboss.soa.update.url = http://download.jboss.org/jbosstools/updates/development/indigo/central/s...
+jboss.soa.update.url = http://download.jboss.org/jbosstools/updates/development/juno/central/soa...
# production (latest release)
-#jboss.soa.update.url = http://download.jboss.org/jbosstools/updates/stable/indigo/central/soa-to...
+#jboss.soa.update.url = http://download.jboss.org/jbosstools/updates/stable/juno/central/soa-tool...
Modified: trunk/build/aggregate/soa-site/site/associate.properties
===================================================================
--- trunk/build/aggregate/soa-site/site/associate.properties 2012-05-28 18:37:19 UTC (rev 41484)
+++ trunk/build/aggregate/soa-site/site/associate.properties 2012-05-28 20:14:03 UTC (rev 41485)
@@ -4,4 +4,4 @@
#update.site.version=3.2.0.M2.2010-07-16_13-26-18-H21
# associate sites to add to the resulting repo
-associate.sites=http://download.jboss.org/jbosstools/updates/indigo/SR2/,http://download.jboss.org/jbosstools/updates/development/indigo/
+associate.sites=http://download.jboss.org/jbosstools/updates/juno/M6/,http://download.jboss.org/jbosstools/updates/development/juno/
Modified: trunk/build/aggregate/soatests-site/site/associate.properties
===================================================================
--- trunk/build/aggregate/soatests-site/site/associate.properties 2012-05-28 18:37:19 UTC (rev 41484)
+++ trunk/build/aggregate/soatests-site/site/associate.properties 2012-05-28 20:14:03 UTC (rev 41485)
@@ -4,4 +4,4 @@
#update.site.version=3.2.0.M2.2010-07-16_13-26-18-H21
# associate sites to add to the resulting repo
-associate.sites=http://download.jboss.org/jbosstools/updates/indigo/SR2/,http://download.jboss.org/jbosstools/updates/development/indigo/,http://download.jboss.org/jbosstools/updates/development/indigo/soa-tooling/
+associate.sites=http://download.jboss.org/jbosstools/updates/juno/M6/,http://download.jboss.org/jbosstools/updates/development/juno/,http://download.jboss.org/jbosstools/updates/development/juno/soa-tooling/
Modified: trunk/build/aggregate/webtools-site/associate.properties
===================================================================
--- trunk/build/aggregate/webtools-site/associate.properties 2012-05-28 18:37:19 UTC (rev 41484)
+++ trunk/build/aggregate/webtools-site/associate.properties 2012-05-28 20:14:03 UTC (rev 41485)
@@ -4,4 +4,4 @@
#update.site.version=3.2.0.M2.2010-07-16_13-26-18-H21
# associate sites to add to the resulting repo
-associate.sites=http://download.jboss.org/jbosstools/updates/indigo/SR2/,http://download.jboss.org/jbosstools/updates/development/indigo/
+associate.sites=http://download.jboss.org/jbosstools/updates/juno/M6/,http://download.jboss.org/jbosstools/updates/development/juno/
13 years, 10 months
JBoss Tools SVN: r41484 - branches/jbosstools-3.3.x/build/aggregate/site.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2012-05-28 14:37:19 -0400 (Mon, 28 May 2012)
New Revision: 41484
Modified:
branches/jbosstools-3.3.x/build/aggregate/site/site.xml
Log:
reorder contents and remove extraneous comments
Modified: branches/jbosstools-3.3.x/build/aggregate/site/site.xml
===================================================================
--- branches/jbosstools-3.3.x/build/aggregate/site/site.xml 2012-05-28 18:20:22 UTC (rev 41483)
+++ branches/jbosstools-3.3.x/build/aggregate/site/site.xml 2012-05-28 18:37:19 UTC (rev 41484)
@@ -1,12 +1,10 @@
<?xml version="1.0" encoding="UTF-8"?>
<site>
- <description>JBoss Tools 3.3 Updates</description>
+ <description>JBoss Tools 3.3 Updates - Core</description>
<!-- PLEASE NOTE!
When updating this file, please be sure that it parses as valid XML before committing it.
To test, just run `mvn clean install` in this folder.
-
- Please also remember to add matching source feature entries to sources/site.xml
-->
<!-- only in JBDS
@@ -168,6 +166,10 @@
<category name="AbridgedTools" />
<category name="MavenTools" />
</feature>
+ <feature url="features/org.jboss.tools.maven.jdt.feature_0.0.0.jar" id="org.jboss.tools.maven.jdt.feature" version="0.0.0">
+ <category name="AbridgedTools" />
+ <category name="MavenTools" />
+ </feature>
<feature url="features/org.jboss.tools.maven.jpa.feature_0.0.0.jar" id="org.jboss.tools.maven.jpa.feature" version="0.0.0">
<category name="AbridgedTools" />
<category name="MavenTools" />
@@ -196,10 +198,6 @@
<category name="AbridgedTools" />
<category name="MavenTools" />
</feature>
- <feature url="features/org.jboss.tools.maven.jdt.feature_0.0.0.jar" id="org.jboss.tools.maven.jdt.feature" version="0.0.0">
- <category name="AbridgedTools" />
- <category name="MavenTools" />
- </feature>
<!-- only in JBT and JBDS Extras -->
<feature url="features/org.jboss.tools.maven.jbosspackaging.feature_0.0.0.jar" id="org.jboss.tools.maven.jbosspackaging.feature" version="0.0.0">
<category name="AbridgedTools" />
13 years, 10 months
JBoss Tools SVN: r41483 - in trunk/examples/plugins/org.jboss.tools.project.examples: src/org/jboss/tools/project/examples/configurators and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2012-05-28 14:20:22 -0400 (Mon, 28 May 2012)
New Revision: 41483
Modified:
trunk/examples/plugins/org.jboss.tools.project.examples/pom.xml
trunk/examples/plugins/org.jboss.tools.project.examples/src/org/jboss/tools/project/examples/configurators/DefaultJBossCentralConfigurator.java
Log:
JBIDE-11622 switch from indigo to juno
Modified: trunk/examples/plugins/org.jboss.tools.project.examples/pom.xml
===================================================================
--- trunk/examples/plugins/org.jboss.tools.project.examples/pom.xml 2012-05-28 18:17:56 UTC (rev 41482)
+++ trunk/examples/plugins/org.jboss.tools.project.examples/pom.xml 2012-05-28 18:20:22 UTC (rev 41483)
@@ -11,20 +11,20 @@
<artifactId>org.jboss.tools.project.examples</artifactId>
<properties>
- <!-- TODO: for GA, change this from /development/indigo/ to /stable/indigo/ -->
- <jboss.discovery.directory.url>http://download.jboss.org/jbosstools/updates/development/indigo/jbosstool...</jboss.discovery.directory.url>
+ <!-- TODO: for GA, change this from /development/juno/ to /stable/juno/ -->
+ <jboss.discovery.directory.url>http://download.jboss.org/jbosstools/updates/development/juno/jbosstools-...</jboss.discovery.directory.url>
</properties>
<profiles>
<!-- _stable_branch jobs could use this profile but the above default (last
stable milestone) is probably better -->
<profile>
- <id>3.3.indigo</id>
+ <id>3.4.juno</id>
<activation>
<activeByDefault>false</activeByDefault>
</activation>
<properties>
- <jboss.discovery.directory.url>http://download.jboss.org/jbosstools/updates/nightly/core/3.3.indigo/jbos...</jboss.discovery.directory.url>
+ <jboss.discovery.directory.url>http://download.jboss.org/jbosstools/updates/nightly/core/3.4.juno/jbosst...</jboss.discovery.directory.url>
</properties>
</profile>
@@ -69,4 +69,4 @@
</plugins>
</build>
-</project>
\ No newline at end of file
+</project>
Modified: trunk/examples/plugins/org.jboss.tools.project.examples/src/org/jboss/tools/project/examples/configurators/DefaultJBossCentralConfigurator.java
===================================================================
--- trunk/central/plugins/org.jboss.tools.central.discovery/plugin.xml 2012-05-28 18:08:41 UTC (rev 41481)
+++ trunk/central/plugins/org.jboss.tools.central.discovery/plugin.xml 2012-05-28 18:17:56 UTC (rev 41482)
@@ -23,7 +23,7 @@
license="Free, EPL"
name="JBoss Maven Integration"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="org.jboss.tools.maven.feature"/>
<icon
image32="images/jbosstools_icon32.png">
@@ -41,7 +41,7 @@
license="Free, EPL"
name="JBoss Maven CDI Configurator"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="org.jboss.tools.maven.cdi.feature"/>
<icon
image32="images/jbosstools_icon32.png">
@@ -59,7 +59,7 @@
license="Free, EPL"
name="JBoss Maven GWT Configurator"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="org.jboss.tools.maven.gwt.feature"/>
<iu id="com.google.gdt.eclipse.suite.e37.feature"/>
<icon
@@ -78,7 +78,7 @@
license="Free, EPL"
name="JBoss Maven Hibernate Configurator"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="org.jboss.tools.maven.hibernate.feature"/>
<icon
image32="images/jbosstools_icon32.png">
@@ -96,7 +96,7 @@
license="Free, EPL"
name="JBoss Maven JAX-RS Configurator"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="org.jboss.tools.maven.jaxrs.feature"/>
<icon
image32="images/jbosstools_icon32.png">
@@ -114,7 +114,7 @@
license="Free, EPL"
name="JBoss Maven JSF Configurator"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="org.jboss.tools.maven.jsf.feature"/>
<icon
image32="images/jbosstools_icon32.png">
@@ -132,7 +132,7 @@
license="Free, EPL"
name="JBoss Maven Portlet Configurator"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="org.jboss.tools.maven.portlet.feature"/>
<icon
image32="images/jbosstools_icon32.png">
@@ -150,7 +150,7 @@
license="Free, EPL"
name="JBoss Maven Seam Configurator"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="org.jboss.tools.maven.seam.feature"/>
<icon
image32="images/jbosstools_icon32.png">
@@ -168,7 +168,7 @@
license="Free, EPL"
name="JBoss Maven JPA Configurator"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="org.jboss.tools.maven.jpa.feature"/>
<icon
image32="images/jbosstools_icon32.png">
@@ -186,7 +186,7 @@
license="Free, EPL"
name="Maven Profile Management UI"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="org.jboss.tools.maven.profiles.feature"/>
<icon
image32="images/jbosstools_icon32.png">
@@ -205,7 +205,7 @@
license="Free, EPL"
name="Maven Integration for Eclipse (m2e)"
provider="eclipse.org"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="org.eclipse.m2e.feature"/>
<icon
image32="images/m2e_32.gif">
@@ -223,7 +223,7 @@
license="Free, EPL"
name="Maven Integration for Eclipse JDT APT (m2e-apt)"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="org.jboss.tools.maven.apt.feature"/>
<icon
image32="images/m2e_32.gif">
@@ -241,7 +241,7 @@
license="Free, EPL"
name="Maven Integration for Web Tools (m2e-wtp)"
provider="eclipse.org"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="org.maven.ide.eclipse.wtp.feature"/>
<icon
image32="images/m2e_32.gif">
@@ -270,7 +270,7 @@
license="Free, EPL"
name="Eclipse EGit"
provider="eclipse.org"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="org.eclipse.egit"/>
<icon
image32="images/egit_32.png">
@@ -288,7 +288,7 @@
license="Free, Subclipse License"
name="Subclipse + SVNKit"
provider="tigris.org"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="org.tigris.subversion.subclipse"/>
<iu id="org.tigris.subversion.clientadapter.svnkit.feature"/>
<icon
@@ -319,7 +319,7 @@
license="Free, LGPL"
name="FindBugs"
provider="FindBugs Project"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="edu.umd.cs.findbugs.plugin.eclipse"/>
<icon
image32="images/findbugs_32.png">
@@ -337,7 +337,7 @@
license="Free, ASL"
name="JSLint"
provider="Rockstarapps.com"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="com.rockstarapps.aws.feature"/>
<iu id="com.rockstarapps.html.core.feature"/>
<iu id="com.rockstarapps.jsLex"/>
@@ -359,7 +359,7 @@
license="Free, EPL"
name="Mylyn Issue Tracker Connectors"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="org.jboss.tools.common.mylyn.feature"/>
<iu id="org.eclipse.mylyn_feature"/>
<iu id="org.eclipse.mylyn.ide_feature"/>
@@ -386,7 +386,7 @@
license="Free, PMD License"
name="PMD"
provider="PMD Developers"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="net.sourceforge.pmd.eclipse"/>
<icon
image32="images/pmd_32.png">
@@ -404,7 +404,7 @@
license="Free, ASL"
name="TestNG"
provider="Cedric Beust"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="org.testng.eclipse"/>
<icon
image32="images/testng_32.gif">
@@ -458,7 +458,7 @@
license="Free, EPL, Other"
name="JST Server"
provider="Eclipse.org"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<!-- <iu id="org.eclipse.jst.server_adapters.ext.feature"/> -->
<iu id="org.eclipse.jst.server_adapters.feature"/>
<iu id="org.eclipse.jst.server_core.feature"/>
@@ -481,7 +481,7 @@
license="EPL, Other"
name="Google Plugin + Web Toolkit"
provider="Google, Inc."
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="com.google.gwt.eclipse.sdkbundle.e37.feature"/>
<iu id="com.google.gdt.eclipse.suite.e37.feature"/>
<icon
@@ -500,7 +500,7 @@
license="Free, EPL, Other"
name="Spring IDE"
provider="Spring IDE Developers"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/juno/central/core/">
<iu id="org.springframework.ide.eclipse.aop.feature"/>
<iu id="org.springframework.ide.eclipse.autowire.feature"/>
<iu id="org.springframework.ide.eclipse.feature"/>
13 years, 10 months
JBoss Tools SVN: r41481 - branches/jbosstools-3.3.x/examples/plugins/org.jboss.tools.project.examples.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2012-05-28 14:08:41 -0400 (Mon, 28 May 2012)
New Revision: 41481
Modified:
branches/jbosstools-3.3.x/examples/plugins/org.jboss.tools.project.examples/pom.xml
Log:
JBIDE-11622 GA, change this from /development/indigo/ to /stable/indigo/
Modified: branches/jbosstools-3.3.x/examples/plugins/org.jboss.tools.project.examples/pom.xml
===================================================================
--- branches/jbosstools-3.3.x/examples/plugins/org.jboss.tools.project.examples/pom.xml 2012-05-28 18:08:34 UTC (rev 41480)
+++ branches/jbosstools-3.3.x/examples/plugins/org.jboss.tools.project.examples/pom.xml 2012-05-28 18:08:41 UTC (rev 41481)
@@ -12,7 +12,7 @@
<properties>
<!-- TODO: for GA, change this from /development/indigo/ to /stable/indigo/ -->
- <jboss.discovery.directory.url>http://download.jboss.org/jbosstools/updates/development/indigo/jbosstool...</jboss.discovery.directory.url>
+ <jboss.discovery.directory.url>http://download.jboss.org/jbosstools/updates/stable/indigo/jbosstools-dir...</jboss.discovery.directory.url>
</properties>
<profiles>
@@ -69,4 +69,4 @@
</plugins>
</build>
-</project>
\ No newline at end of file
+</project>
13 years, 10 months
JBoss Tools SVN: r41480 - branches/jbosstools-3.3.x/central/plugins/org.jboss.tools.central.discovery.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2012-05-28 14:08:34 -0400 (Mon, 28 May 2012)
New Revision: 41480
Modified:
branches/jbosstools-3.3.x/central/plugins/org.jboss.tools.central.discovery/plugin.xml
Log:
JBIDE-11622 point central at /stable/ intead of /development/ URL
Modified: branches/jbosstools-3.3.x/central/plugins/org.jboss.tools.central.discovery/plugin.xml
===================================================================
--- branches/jbosstools-3.3.x/central/plugins/org.jboss.tools.central.discovery/plugin.xml 2012-05-28 17:24:57 UTC (rev 41479)
+++ branches/jbosstools-3.3.x/central/plugins/org.jboss.tools.central.discovery/plugin.xml 2012-05-28 18:08:34 UTC (rev 41480)
@@ -23,7 +23,7 @@
license="Free, EPL"
name="JBoss Maven Integration"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="org.jboss.tools.maven.feature"/>
<icon
image32="images/jbosstools_icon32.png">
@@ -41,7 +41,7 @@
license="Free, EPL"
name="JBoss Maven CDI Configurator"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="org.jboss.tools.maven.cdi.feature"/>
<icon
image32="images/jbosstools_icon32.png">
@@ -59,7 +59,7 @@
license="Free, EPL"
name="JBoss Maven GWT Configurator"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="org.jboss.tools.maven.gwt.feature"/>
<iu id="com.google.gdt.eclipse.suite.e37.feature"/>
<icon
@@ -78,7 +78,7 @@
license="Free, EPL"
name="JBoss Maven Hibernate Configurator"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="org.jboss.tools.maven.hibernate.feature"/>
<icon
image32="images/jbosstools_icon32.png">
@@ -96,7 +96,7 @@
license="Free, EPL"
name="JBoss Maven JAX-RS Configurator"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="org.jboss.tools.maven.jaxrs.feature"/>
<icon
image32="images/jbosstools_icon32.png">
@@ -114,7 +114,7 @@
license="Free, EPL"
name="JBoss Maven JSF Configurator"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="org.jboss.tools.maven.jsf.feature"/>
<icon
image32="images/jbosstools_icon32.png">
@@ -132,7 +132,7 @@
license="Free, EPL"
name="JBoss Maven Portlet Configurator"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="org.jboss.tools.maven.portlet.feature"/>
<icon
image32="images/jbosstools_icon32.png">
@@ -150,7 +150,7 @@
license="Free, EPL"
name="JBoss Maven Seam Configurator"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="org.jboss.tools.maven.seam.feature"/>
<icon
image32="images/jbosstools_icon32.png">
@@ -168,7 +168,7 @@
license="Free, EPL"
name="JBoss Maven JPA Configurator"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="org.jboss.tools.maven.jpa.feature"/>
<icon
image32="images/jbosstools_icon32.png">
@@ -186,7 +186,7 @@
license="Free, EPL"
name="Maven Profile Management UI"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="org.jboss.tools.maven.profiles.feature"/>
<icon
image32="images/jbosstools_icon32.png">
@@ -205,7 +205,7 @@
license="Free, EPL"
name="Maven Integration for Eclipse (m2e)"
provider="eclipse.org"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="org.eclipse.m2e.feature"/>
<icon
image32="images/m2e_32.gif">
@@ -223,7 +223,7 @@
license="Free, EPL"
name="Maven Integration for Eclipse JDT APT (m2e-apt)"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="org.jboss.tools.maven.apt.feature"/>
<icon
image32="images/m2e_32.gif">
@@ -241,7 +241,7 @@
license="Free, EPL"
name="Maven Integration for Web Tools (m2e-wtp)"
provider="eclipse.org"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="org.maven.ide.eclipse.wtp.feature"/>
<icon
image32="images/m2e_32.gif">
@@ -270,7 +270,7 @@
license="Free, EPL"
name="Eclipse EGit"
provider="eclipse.org"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="org.eclipse.egit"/>
<icon
image32="images/egit_32.png">
@@ -288,7 +288,7 @@
license="Free, Subclipse License"
name="Subclipse + SVNKit"
provider="tigris.org"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="org.tigris.subversion.subclipse"/>
<iu id="org.tigris.subversion.clientadapter.svnkit.feature"/>
<icon
@@ -319,7 +319,7 @@
license="Free, LGPL"
name="FindBugs"
provider="FindBugs Project"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="edu.umd.cs.findbugs.plugin.eclipse"/>
<icon
image32="images/findbugs_32.png">
@@ -337,7 +337,7 @@
license="Free, ASL"
name="JSLint"
provider="Rockstarapps.com"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="com.rockstarapps.aws.feature"/>
<iu id="com.rockstarapps.html.core.feature"/>
<iu id="com.rockstarapps.jsLex"/>
@@ -359,7 +359,7 @@
license="Free, EPL"
name="Mylyn Issue Tracker Connectors"
provider="JBoss by Red Hat"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="org.jboss.tools.common.mylyn.feature"/>
<iu id="org.eclipse.mylyn_feature"/>
<iu id="org.eclipse.mylyn.ide_feature"/>
@@ -386,7 +386,7 @@
license="Free, PMD License"
name="PMD"
provider="PMD Developers"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="net.sourceforge.pmd.eclipse"/>
<icon
image32="images/pmd_32.png">
@@ -404,7 +404,7 @@
license="Free, ASL"
name="TestNG"
provider="Cedric Beust"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="org.testng.eclipse"/>
<icon
image32="images/testng_32.gif">
@@ -458,7 +458,7 @@
license="Free, EPL, Other"
name="JST Server"
provider="Eclipse.org"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<!-- <iu id="org.eclipse.jst.server_adapters.ext.feature"/> -->
<iu id="org.eclipse.jst.server_adapters.feature"/>
<iu id="org.eclipse.jst.server_core.feature"/>
@@ -481,7 +481,7 @@
license="EPL, Other"
name="Google Plugin + Web Toolkit"
provider="Google, Inc."
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="com.google.gwt.eclipse.sdkbundle.e37.feature"/>
<iu id="com.google.gdt.eclipse.suite.e37.feature"/>
<icon
@@ -500,7 +500,7 @@
license="Free, EPL, Other"
name="Spring IDE"
provider="Spring IDE Developers"
- siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/central/c...">
+ siteUrl="http://download.jboss.org/jbosstools/updates/stable/indigo/central/core/">
<iu id="org.springframework.ide.eclipse.aop.feature"/>
<iu id="org.springframework.ide.eclipse.autowire.feature"/>
<iu id="org.springframework.ide.eclipse.feature"/>
13 years, 10 months
JBoss Tools SVN: r41479 - trunk/build/aggregate/site.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2012-05-28 13:24:57 -0400 (Mon, 28 May 2012)
New Revision: 41479
Modified:
trunk/build/aggregate/site/site.xml
Log:
reorder file to match JBDS
Modified: trunk/build/aggregate/site/site.xml
===================================================================
--- trunk/build/aggregate/site/site.xml 2012-05-28 17:18:48 UTC (rev 41478)
+++ trunk/build/aggregate/site/site.xml 2012-05-28 17:24:57 UTC (rev 41479)
@@ -1,12 +1,10 @@
<?xml version="1.0" encoding="UTF-8"?>
<site>
- <description>JBoss Tools 3.3 Updates</description>
+ <description>JBoss Tools 3.3 Updates - Core</description>
<!-- PLEASE NOTE!
When updating this file, please be sure that it parses as valid XML before committing it.
To test, just run `mvn clean install` in this folder.
-
- Please also remember to add matching source feature entries to sources/site.xml
-->
<!-- only in JBDS
@@ -168,6 +166,10 @@
<category name="AbridgedTools" />
<category name="MavenTools" />
</feature>
+ <feature url="features/org.jboss.tools.maven.jdt.feature_0.0.0.jar" id="org.jboss.tools.maven.jdt.feature" version="0.0.0">
+ <category name="AbridgedTools" />
+ <category name="MavenTools" />
+ </feature>
<feature url="features/org.jboss.tools.maven.jpa.feature_0.0.0.jar" id="org.jboss.tools.maven.jpa.feature" version="0.0.0">
<category name="AbridgedTools" />
<category name="MavenTools" />
@@ -196,10 +198,6 @@
<category name="AbridgedTools" />
<category name="MavenTools" />
</feature>
- <feature url="features/org.jboss.tools.maven.jdt.feature_0.0.0.jar" id="org.jboss.tools.maven.jdt.feature" version="0.0.0">
- <category name="AbridgedTools" />
- <category name="MavenTools" />
- </feature>
<!-- only in JBT and JBDS Extras -->
<feature url="features/org.jboss.tools.maven.jbosspackaging.feature_0.0.0.jar" id="org.jboss.tools.maven.jbosspackaging.feature" version="0.0.0">
<category name="AbridgedTools" />
13 years, 10 months
JBoss Tools SVN: r41478 - trunk/build/target-platform.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2012-05-28 13:18:48 -0400 (Mon, 28 May 2012)
New Revision: 41478
Modified:
trunk/build/target-platform/jbds-junoM6.target
trunk/build/target-platform/jbds-junoM6.target.p2mirror.xml
trunk/build/target-platform/jbds.target
trunk/build/target-platform/jbds.target.p2mirror.xml
trunk/build/target-platform/multiple-junoM6.target
trunk/build/target-platform/multiple-junoM6.target.p2mirror.xml
trunk/build/target-platform/multiple.target
trunk/build/target-platform/multiple.target.p2mirror.xml
trunk/build/target-platform/unified-junoM6.target
trunk/build/target-platform/unified-junoM6.target.p2mirror.xml
trunk/build/target-platform/unified.target
trunk/build/target-platform/unified.target.p2mirror.xml
Log:
JBIDE-11961 remove 4 BPEL features from JBT/JBDS target platforms
Modified: trunk/build/target-platform/jbds-junoM6.target
===================================================================
--- trunk/build/target-platform/jbds-junoM6.target 2012-05-28 16:13:26 UTC (rev 41477)
+++ trunk/build/target-platform/jbds-junoM6.target 2012-05-28 17:18:48 UTC (rev 41478)
@@ -52,12 +52,6 @@
<unit id="org.apache.lucene.snowball" version="2.9.1.v20100421-0704"/>
<unit id="org.apache.lucene.spellchecker" version="2.9.1.v20100421-0704"/>
- <!-- Eclipse BPEL -->
- <unit id="org.eclipse.bpel.common.feature.feature.group" version="0.8.0.v20120313-1037-CI"/>
- <unit id="org.eclipse.bpel.jboss.riftsaw.runtime.feature.feature.group" version="0.8.0.v20120313-1037-CI"/>
- <unit id="org.eclipse.bpel.apache.ode.runtime.feature.feature.group" version="0.8.0.v20120313-1037-CI"/>
- <unit id="org.eclipse.bpel.feature.feature.group" version="0.8.0.v20120313-1037-CI"/>
-
<!-- EMF, XSD -->
<unit id="org.eclipse.emf.feature.group" version="2.8.0.v20120319-0555"/>
<unit id="org.eclipse.emf.workspace.feature.group" version="1.5.0.v20110502-1600-36-8s734C367E3CBC7"/>
@@ -274,4 +268,4 @@
<unit id="com.google.gwt.eclipse.sdkbundle.e37.feature.feature.group" version="2.4.0.v201201120043-rel-r37"/>
</location>
</locations>
-</target>
\ No newline at end of file
+</target>
Modified: trunk/build/target-platform/jbds-junoM6.target.p2mirror.xml
===================================================================
--- trunk/build/target-platform/jbds-junoM6.target.p2mirror.xml 2012-05-28 16:13:26 UTC (rev 41477)
+++ trunk/build/target-platform/jbds-junoM6.target.p2mirror.xml 2012-05-28 17:18:48 UTC (rev 41478)
@@ -61,10 +61,6 @@
<iu id="org.apache.lucene.queries" version=""/>
<iu id="org.apache.lucene.snowball" version=""/>
<iu id="org.apache.lucene.spellchecker" version=""/>
-<iu id="org.eclipse.bpel.common.feature.feature.group" version=""/>
-<iu id="org.eclipse.bpel.jboss.riftsaw.runtime.feature.feature.group" version=""/>
-<iu id="org.eclipse.bpel.apache.ode.runtime.feature.feature.group" version=""/>
-<iu id="org.eclipse.bpel.feature.feature.group" version=""/>
<iu id="org.eclipse.emf.feature.group" version=""/>
<iu id="org.eclipse.emf.workspace.feature.group" version=""/>
<iu id="org.eclipse.emf.validation.feature.group" version=""/>
Modified: trunk/build/target-platform/jbds.target
===================================================================
--- trunk/build/target-platform/jbds.target 2012-05-28 16:13:26 UTC (rev 41477)
+++ trunk/build/target-platform/jbds.target 2012-05-28 17:18:48 UTC (rev 41478)
@@ -52,12 +52,6 @@
<unit id="org.apache.lucene.snowball" version="2.9.1.v20100421-0704"/>
<unit id="org.apache.lucene.spellchecker" version="2.9.1.v20100421-0704"/>
- <!-- Eclipse BPEL -->
- <unit id="org.eclipse.bpel.common.feature.feature.group" version="0.8.0.v20120209-1201-H138-CI"/>
- <unit id="org.eclipse.bpel.jboss.riftsaw.runtime.feature.feature.group" version="0.8.0.v20120209-1201-H138-CI"/>
- <unit id="org.eclipse.bpel.apache.ode.runtime.feature.feature.group" version="0.8.0.v20120209-1201-H138-CI"/>
- <unit id="org.eclipse.bpel.feature.feature.group" version="0.8.0.v20120209-1201-H138-CI"/>
-
<!-- EMF, XSD -->
<unit id="org.eclipse.emf.feature.group" version="2.7.2.v20120130-0943"/>
<unit id="org.eclipse.emf.workspace.feature.group" version="1.5.1.v20110823-1800-37708s734D3C7D3CCC1"/>
Modified: trunk/build/target-platform/jbds.target.p2mirror.xml
===================================================================
--- trunk/build/target-platform/jbds.target.p2mirror.xml 2012-05-28 16:13:26 UTC (rev 41477)
+++ trunk/build/target-platform/jbds.target.p2mirror.xml 2012-05-28 17:18:48 UTC (rev 41478)
@@ -61,10 +61,6 @@
<iu id="org.apache.lucene.queries" version=""/>
<iu id="org.apache.lucene.snowball" version=""/>
<iu id="org.apache.lucene.spellchecker" version=""/>
-<iu id="org.eclipse.bpel.common.feature.feature.group" version=""/>
-<iu id="org.eclipse.bpel.jboss.riftsaw.runtime.feature.feature.group" version=""/>
-<iu id="org.eclipse.bpel.apache.ode.runtime.feature.feature.group" version=""/>
-<iu id="org.eclipse.bpel.feature.feature.group" version=""/>
<iu id="org.eclipse.emf.feature.group" version=""/>
<iu id="org.eclipse.emf.workspace.feature.group" version=""/>
<iu id="org.eclipse.emf.validation.feature.group" version=""/>
Modified: trunk/build/target-platform/multiple-junoM6.target
===================================================================
--- trunk/build/target-platform/multiple-junoM6.target 2012-05-28 16:13:26 UTC (rev 41477)
+++ trunk/build/target-platform/multiple-junoM6.target 2012-05-28 17:18:48 UTC (rev 41478)
@@ -54,12 +54,6 @@
<unit id="org.apache.lucene.snowball" version="2.9.1.v20100421-0704"/>
<unit id="org.apache.lucene.spellchecker" version="2.9.1.v20100421-0704"/>
- <!-- Eclipse BPEL -->
- <unit id="org.eclipse.bpel.common.feature.feature.group" version="0.8.0.v20120313-1037-CI"/>
- <unit id="org.eclipse.bpel.jboss.riftsaw.runtime.feature.feature.group" version="0.8.0.v20120313-1037-CI"/>
- <unit id="org.eclipse.bpel.apache.ode.runtime.feature.feature.group" version="0.8.0.v20120313-1037-CI"/>
- <unit id="org.eclipse.bpel.feature.feature.group" version="0.8.0.v20120313-1037-CI"/>
-
<!-- EMF, XSD -->
<unit id="org.eclipse.emf.workspace.feature.group" version="1.5.0.v20110502-1600-36-8s734C367E3CBC7"/>
<unit id="org.eclipse.emf.validation.feature.group" version="1.5.0.v20110502-1600-479-9oB56N5BBR6LCA6"/>
Modified: trunk/build/target-platform/multiple-junoM6.target.p2mirror.xml
===================================================================
--- trunk/build/target-platform/multiple-junoM6.target.p2mirror.xml 2012-05-28 16:13:26 UTC (rev 41477)
+++ trunk/build/target-platform/multiple-junoM6.target.p2mirror.xml 2012-05-28 17:18:48 UTC (rev 41478)
@@ -61,10 +61,6 @@
<iu id="org.apache.lucene.queries" version=""/>
<iu id="org.apache.lucene.snowball" version=""/>
<iu id="org.apache.lucene.spellchecker" version=""/>
-<iu id="org.eclipse.bpel.common.feature.feature.group" version=""/>
-<iu id="org.eclipse.bpel.jboss.riftsaw.runtime.feature.feature.group" version=""/>
-<iu id="org.eclipse.bpel.apache.ode.runtime.feature.feature.group" version=""/>
-<iu id="org.eclipse.bpel.feature.feature.group" version=""/>
<iu id="org.eclipse.emf.workspace.feature.group" version=""/>
<iu id="org.eclipse.emf.validation.feature.group" version=""/>
<iu id="org.eclipse.emf.transaction.feature.group" version=""/>
Modified: trunk/build/target-platform/multiple.target
===================================================================
--- trunk/build/target-platform/multiple.target 2012-05-28 16:13:26 UTC (rev 41477)
+++ trunk/build/target-platform/multiple.target 2012-05-28 17:18:48 UTC (rev 41478)
@@ -54,12 +54,6 @@
<unit id="org.apache.lucene.snowball" version="2.9.1.v20100421-0704"/>
<unit id="org.apache.lucene.spellchecker" version="2.9.1.v20100421-0704"/>
- <!-- Eclipse BPEL -->
- <unit id="org.eclipse.bpel.common.feature.feature.group" version="0.8.0.v20120209-1201-H138-CI"/>
- <unit id="org.eclipse.bpel.jboss.riftsaw.runtime.feature.feature.group" version="0.8.0.v20120209-1201-H138-CI"/>
- <unit id="org.eclipse.bpel.apache.ode.runtime.feature.feature.group" version="0.8.0.v20120209-1201-H138-CI"/>
- <unit id="org.eclipse.bpel.feature.feature.group" version="0.8.0.v20120209-1201-H138-CI"/>
-
<!-- EMF, XSD -->
<unit id="org.eclipse.emf.workspace.feature.group" version="1.5.1.v20110823-1800-37708s734D3C7D3CCC1"/>
<unit id="org.eclipse.emf.validation.feature.group" version="1.5.0.v20110502-1600-479-9oB56N5BBR6LCA6"/>
Modified: trunk/build/target-platform/multiple.target.p2mirror.xml
===================================================================
--- trunk/build/target-platform/multiple.target.p2mirror.xml 2012-05-28 16:13:26 UTC (rev 41477)
+++ trunk/build/target-platform/multiple.target.p2mirror.xml 2012-05-28 17:18:48 UTC (rev 41478)
@@ -62,10 +62,6 @@
<iu id="org.apache.lucene.queries" version=""/>
<iu id="org.apache.lucene.snowball" version=""/>
<iu id="org.apache.lucene.spellchecker" version=""/>
-<iu id="org.eclipse.bpel.common.feature.feature.group" version=""/>
-<iu id="org.eclipse.bpel.jboss.riftsaw.runtime.feature.feature.group" version=""/>
-<iu id="org.eclipse.bpel.apache.ode.runtime.feature.feature.group" version=""/>
-<iu id="org.eclipse.bpel.feature.feature.group" version=""/>
<iu id="org.eclipse.emf.workspace.feature.group" version=""/>
<iu id="org.eclipse.emf.validation.feature.group" version=""/>
<iu id="org.eclipse.emf.transaction.feature.group" version=""/>
Modified: trunk/build/target-platform/unified-junoM6.target
===================================================================
--- trunk/build/target-platform/unified-junoM6.target 2012-05-28 16:13:26 UTC (rev 41477)
+++ trunk/build/target-platform/unified-junoM6.target 2012-05-28 17:18:48 UTC (rev 41478)
@@ -54,12 +54,6 @@
<unit id="org.apache.lucene.snowball" version="2.9.1.v20100421-0704"/>
<unit id="org.apache.lucene.spellchecker" version="2.9.1.v20100421-0704"/>
- <!-- Eclipse BPEL -->
- <unit id="org.eclipse.bpel.common.feature.feature.group" version="0.8.0.v20120313-1037-CI"/>
- <unit id="org.eclipse.bpel.jboss.riftsaw.runtime.feature.feature.group" version="0.8.0.v20120313-1037-CI"/>
- <unit id="org.eclipse.bpel.apache.ode.runtime.feature.feature.group" version="0.8.0.v20120313-1037-CI"/>
- <unit id="org.eclipse.bpel.feature.feature.group" version="0.8.0.v20120313-1037-CI"/>
-
<!-- EMF, XSD -->
<unit id="org.eclipse.emf.workspace.feature.group" version="1.5.0.v20110502-1600-36-8s734C367E3CBC7"/>
<unit id="org.eclipse.emf.validation.feature.group" version="1.5.0.v20110502-1600-479-9oB56N5BBR6LCA6"/>
Modified: trunk/build/target-platform/unified-junoM6.target.p2mirror.xml
===================================================================
--- trunk/build/target-platform/unified-junoM6.target.p2mirror.xml 2012-05-28 16:13:26 UTC (rev 41477)
+++ trunk/build/target-platform/unified-junoM6.target.p2mirror.xml 2012-05-28 17:18:48 UTC (rev 41478)
@@ -61,10 +61,6 @@
<iu id="org.apache.lucene.queries" version=""/>
<iu id="org.apache.lucene.snowball" version=""/>
<iu id="org.apache.lucene.spellchecker" version=""/>
-<iu id="org.eclipse.bpel.common.feature.feature.group" version=""/>
-<iu id="org.eclipse.bpel.jboss.riftsaw.runtime.feature.feature.group" version=""/>
-<iu id="org.eclipse.bpel.apache.ode.runtime.feature.feature.group" version=""/>
-<iu id="org.eclipse.bpel.feature.feature.group" version=""/>
<iu id="org.eclipse.emf.workspace.feature.group" version=""/>
<iu id="org.eclipse.emf.validation.feature.group" version=""/>
<iu id="org.eclipse.emf.transaction.feature.group" version=""/>
Modified: trunk/build/target-platform/unified.target
===================================================================
--- trunk/build/target-platform/unified.target 2012-05-28 16:13:26 UTC (rev 41477)
+++ trunk/build/target-platform/unified.target 2012-05-28 17:18:48 UTC (rev 41478)
@@ -54,12 +54,6 @@
<unit id="org.apache.lucene.snowball" version="2.9.1.v20100421-0704"/>
<unit id="org.apache.lucene.spellchecker" version="2.9.1.v20100421-0704"/>
- <!-- Eclipse BPEL -->
- <unit id="org.eclipse.bpel.common.feature.feature.group" version="0.8.0.v20120209-1201-H138-CI"/>
- <unit id="org.eclipse.bpel.jboss.riftsaw.runtime.feature.feature.group" version="0.8.0.v20120209-1201-H138-CI"/>
- <unit id="org.eclipse.bpel.apache.ode.runtime.feature.feature.group" version="0.8.0.v20120209-1201-H138-CI"/>
- <unit id="org.eclipse.bpel.feature.feature.group" version="0.8.0.v20120209-1201-H138-CI"/>
-
<!-- EMF, XSD -->
<unit id="org.eclipse.emf.workspace.feature.group" version="1.5.1.v20110823-1800-37708s734D3C7D3CCC1"/>
<unit id="org.eclipse.emf.validation.feature.group" version="1.5.0.v20110502-1600-479-9oB56N5BBR6LCA6"/>
Modified: trunk/build/target-platform/unified.target.p2mirror.xml
===================================================================
--- trunk/build/target-platform/unified.target.p2mirror.xml 2012-05-28 16:13:26 UTC (rev 41477)
+++ trunk/build/target-platform/unified.target.p2mirror.xml 2012-05-28 17:18:48 UTC (rev 41478)
@@ -62,10 +62,6 @@
<iu id="org.apache.lucene.queries" version=""/>
<iu id="org.apache.lucene.snowball" version=""/>
<iu id="org.apache.lucene.spellchecker" version=""/>
-<iu id="org.eclipse.bpel.common.feature.feature.group" version=""/>
-<iu id="org.eclipse.bpel.jboss.riftsaw.runtime.feature.feature.group" version=""/>
-<iu id="org.eclipse.bpel.apache.ode.runtime.feature.feature.group" version=""/>
-<iu id="org.eclipse.bpel.feature.feature.group" version=""/>
<iu id="org.eclipse.emf.workspace.feature.group" version=""/>
<iu id="org.eclipse.emf.validation.feature.group" version=""/>
<iu id="org.eclipse.emf.transaction.feature.group" version=""/>
13 years, 10 months
JBoss Tools SVN: r41477 - trunk/maven/plugins/org.jboss.tools.maven.core/src/org/jboss/tools/maven/core.
by jbosstools-commits@lists.jboss.org
Author: fbricon
Date: 2012-05-28 12:13:26 -0400 (Mon, 28 May 2012)
New Revision: 41477
Modified:
trunk/maven/plugins/org.jboss.tools.maven.core/src/org/jboss/tools/maven/core/MavenCoreActivator.java
Log:
Bump maven-compiler-plugin version to 2.5
Modified: trunk/maven/plugins/org.jboss.tools.maven.core/src/org/jboss/tools/maven/core/MavenCoreActivator.java
===================================================================
--- trunk/maven/plugins/org.jboss.tools.maven.core/src/org/jboss/tools/maven/core/MavenCoreActivator.java 2012-05-28 13:46:39 UTC (rev 41476)
+++ trunk/maven/plugins/org.jboss.tools.maven.core/src/org/jboss/tools/maven/core/MavenCoreActivator.java 2012-05-28 16:13:26 UTC (rev 41477)
@@ -716,7 +716,7 @@
org.apache.maven.model.Plugin plugin = new org.apache.maven.model.Plugin();
plugin.setGroupId("org.apache.maven.plugins"); //$NON-NLS-1$
plugin.setArtifactId("maven-compiler-plugin"); //$NON-NLS-1$
- plugin.setVersion("2.4");
+ plugin.setVersion("2.5");
Xpp3Dom configuration = new Xpp3Dom( "configuration" ); //$NON-NLS-1$
Xpp3Dom source = new Xpp3Dom("source"); //$NON-NLS-1$
source.setValue(compilerLevel); //$NON-NLS-1$
13 years, 10 months
JBoss Tools SVN: r41476 - in trunk/examples/plugins/org.jboss.tools.project.examples/src/org/jboss/tools/project/examples: preferences and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: snjeza
Date: 2012-05-28 09:46:39 -0400 (Mon, 28 May 2012)
New Revision: 41476
Modified:
trunk/examples/plugins/org.jboss.tools.project.examples/src/org/jboss/tools/project/examples/model/ProjectExampleUtil.java
trunk/examples/plugins/org.jboss.tools.project.examples/src/org/jboss/tools/project/examples/preferences/ProjectExamplesPreferencePage.java
trunk/examples/plugins/org.jboss.tools.project.examples/src/org/jboss/tools/project/examples/preferences/Sites.java
Log:
JBIDE-11727 - explore providing an .project_example.xml file in root of quickstarts distributions for easy loading/detection in jboss tools
Modified: trunk/examples/plugins/org.jboss.tools.project.examples/src/org/jboss/tools/project/examples/model/ProjectExampleUtil.java
===================================================================
--- trunk/examples/plugins/org.jboss.tools.project.examples/src/org/jboss/tools/project/examples/model/ProjectExampleUtil.java 2012-05-28 10:51:49 UTC (rev 41475)
+++ trunk/examples/plugins/org.jboss.tools.project.examples/src/org/jboss/tools/project/examples/model/ProjectExampleUtil.java 2012-05-28 13:46:39 UTC (rev 41476)
@@ -146,11 +146,17 @@
}
public static Set<IProjectExampleSite> getRuntimeSites() {
+ return getRuntimeSites(false);
+ }
+
+ public static Set<IProjectExampleSite> getRuntimeSites(boolean force) {
Set<IProjectExampleSite> sites = new HashSet<IProjectExampleSite>();
- IPreferenceStore store = ProjectExamplesActivator.getDefault()
- .getPreferenceStore();
- if (!store.getBoolean(ProjectExamplesActivator.SHOW_RUNTIME_SITES)) {
- return sites;
+ if (!force) {
+ IPreferenceStore store = ProjectExamplesActivator.getDefault()
+ .getPreferenceStore();
+ if (!store.getBoolean(ProjectExamplesActivator.SHOW_RUNTIME_SITES)) {
+ return sites;
+ }
}
IServer[] servers = ServerCore.getServers();
for (IServer server:servers) {
Modified: trunk/examples/plugins/org.jboss.tools.project.examples/src/org/jboss/tools/project/examples/preferences/ProjectExamplesPreferencePage.java
===================================================================
--- trunk/examples/plugins/org.jboss.tools.project.examples/src/org/jboss/tools/project/examples/preferences/ProjectExamplesPreferencePage.java 2012-05-28 10:51:49 UTC (rev 41475)
+++ trunk/examples/plugins/org.jboss.tools.project.examples/src/org/jboss/tools/project/examples/preferences/ProjectExamplesPreferencePage.java 2012-05-28 13:46:39 UTC (rev 41476)
@@ -154,8 +154,6 @@
showInvalidSites.setText(Messages.ProjectExamplesPreferencePage_Show_invalid_sites);
showInvalidSites.setSelection(store.getBoolean(ProjectExamplesActivator.SHOW_INVALID_SITES));
-
-
Group sitesGroup = new Group(composite,SWT.NONE);
sitesGroup.setText(Messages.ProjectExamplesPreferencePage_Sites);
GridLayout gl = new GridLayout(2,false);
Modified: trunk/examples/plugins/org.jboss.tools.project.examples/src/org/jboss/tools/project/examples/preferences/Sites.java
===================================================================
--- trunk/examples/plugins/org.jboss.tools.project.examples/src/org/jboss/tools/project/examples/preferences/Sites.java 2012-05-28 10:51:49 UTC (rev 41475)
+++ trunk/examples/plugins/org.jboss.tools.project.examples/src/org/jboss/tools/project/examples/preferences/Sites.java 2012-05-28 13:46:39 UTC (rev 41476)
@@ -45,7 +45,7 @@
siteCategories[1]=pluginSite;
runtimeSite = new SiteCategory(Messages.Sites_Runtime_sites);
- Set<IProjectExampleSite> runtimeSites = ProjectExampleUtil.getRuntimeSites();
+ Set<IProjectExampleSite> runtimeSites = ProjectExampleUtil.getRuntimeSites(true);
runtimeSite.setSites(runtimeSites);
siteCategories[2]= runtimeSite;
13 years, 10 months
--- trunk/examples/plugins/org.jboss.tools.project.examples/src/org/jboss/tools/project/examples/configurators/DefaultJBossCentralConfigurator.java 2012-05-28 18:17:56 UTC (rev 41482)
+++ trunk/examples/plugins/org.jboss.tools.project.examples/src/org/jboss/tools/project/examples/configurators/DefaultJBossCentralConfigurator.java 2012-05-28 18:20:22 UTC (rev 41483)
@@ -41,8 +41,8 @@
WIZARD_IDS = Collections.unmodifiableList(wizardIds);
}
- // TODO: for GA, change this from /development/indigo/ to /stable/indigo/
- private static final String JBOSS_DIRECTORY_URL_DEFAULT = "http://download.jboss.org/jbosstools/updates/development/indigo/jbosstool..."; //$NON-NLS-1$
+ // TODO: for GA, change this from /development/juno/ to /stable/juno/
+ private static final String JBOSS_DIRECTORY_URL_DEFAULT = "http://download.jboss.org/jbosstools/updates/development/juno/jbosstools-..."; //$NON-NLS-1$
// see pom.xml for actual value -- this is passed it at build-time via Maven
private static final String JBOSS_DIRECTORY_URL;
13 years, 10 months
JBoss Tools SVN: r41482 - trunk/central/plugins/org.jboss.tools.central.discovery.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2012-05-28 14:17:56 -0400 (Mon, 28 May 2012)
New Revision: 41482
Modified:
trunk/central/plugins/org.jboss.tools.central.discovery/plugin.xml
Log:
point central at forthcoming Juno site
Modified: trunk/central/plugins/org.jboss.tools.central.discovery/plugin.xml
===================================================================